@@ -1,4 +1,4 @@
-import requests
+from requests_futures.sessions import FuturesSession
 import json
 from .error import validate
 
@@ -17,6 +17,13 @@ class Resource(object):
     """
     def __init__(self, uri, **kwargs):
         self.uri = uri
+
+        if 'session' in kwargs.keys():
+            self._session = kwargs['session']
+            del kwargs['session']
+        else:
+            self._session = FuturesSession()
+        
         self._set_options(**kwargs)
 
     def _set_options(self, **kwargs):
@@ -37,6 +44,9 @@ class Resource(object):
         else:
             return self.uri
 
+    def _validate(self, session, response):
+        validate(response)
+
     def _make_request(self, method, path='', **kwargs):
         kwargs.update(self.opts)
         # normalize `params` kwarg according to method
@@ -44,18 +54,14 @@ class Resource(object):
             if 'params' in kwargs:
                 kwargs['data'] = json.dumps(kwargs['params'])
                 del kwargs['params']
-        response = getattr(
-            requests,
+        future = getattr(
+            self._session,
             method)(
                 self._make_url(
                     path),
+                background_callback=self._validate,
                 **kwargs)
-        # handle errors
-        validate(response)
-        # handle cookies
-        if response.cookies:
-            self._set_options(cookies=response.cookies)
-        return response
+        return future
 
     def get(self, path='', **kwargs):
         """
